# 常用函数包

-
    1. 项目根目录下必须包含config.py文件

- 支付接口编写规范：
  支付服务_代码规范.py

# 更细说明

- 1.0.69 : 更新 Errors.py中的异常码
- 1.0.70 : 阿里云 异步短信验证码接口.  注意: 阿里云SDK需单独安装, 安装包在需要用的功能文件中列出
- 1.0.71 : 调整异步短信接口命名 
  - SMS_发送短息ASYNC --> SMS_发送短信v2.py
  - "SMS_发送短信v2", 合并同步短信接口,统一使用阿里V2 SDK.
- 1.0.72 : 新增: msvc_user_auth 手机登录\注册相关 interface , api 
- 1.0.73 : msvc_user_auth  interface异常返回,少嵌套一层detail
- 1.0.80 : 更改： 微信支付SDK - 分离V1和V2两个版本, V1版本需要手动更改库中config.py文件的配置
- 1.0.81 : 修改: config.py文件中的 支付宝配置为路径
- 1.0.82 : ERROR code 增加: 数据查询失败, 数据增加失败, 数据删除失败, 数据更新失败
- 1.0.83 : Funcs/fastapi_logger.py 优化,可自主设置logger文件名
- 1.0.84 : 修复logger bug, 新增异步文件logger
- 1.0.85 : 阿里云 发送短信, 更改 短信模板传参类型为str
